/*
 * Allgemeine Funktionen mit und ohne Datenverteilerbezug
 * Copyright (C) 2007 BitCtrl Systems GmbH
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.sys.funclib.bitctrl.modell;

import de.bsvrz.sys.funclib.bitctrl.modell.att.Attributliste;

/**
 * Gemeinsame Schnittstelle für Daten eines Datensatzes.
 *
 * @author BitCtrl Systems GmbH, Falko Schumann
 */
public interface Datum extends Attributliste {

	/**
	 * Erzeugt eine tiefe Kopie des Datums.
	 *
	 * @return die Kopie.
	 */
	@Override
	Datum clone();

	/**
	 * Gibt den Datensatz zurück, zu dem das Datum gehört.
	 *
	 * @return der dazugehörige Datensatz zum Datum.
	 */
	Datensatz dGetDatensatz();

	/**
	 * Gibt den Aspekt des Datums zurück. Der Aspekt kann <code>null</code>
	 * sein, z.&nbsp;B. wenn das Datum nicht vom Modell sondern Client erzeugt
	 * wurde.
	 *
	 * @return der Aspekt oder <code>null</code>, wenn noch kein Aspekt
	 *         zugeordnet wurde.
	 */
	Aspekt dGetAspekt();

}
