package de.bsvrz.sys.funclib.bitctrl.modell.impl;

import de.bsvrz.sys.funclib.bitctrl.modell.Aspekt;
import de.bsvrz.sys.funclib.bitctrl.modell.Datensatz;
import de.bsvrz.sys.funclib.bitctrl.modell.Datum;

/**
 * Implementietr die allgemeinen Funktionen der Schnittstelle.
 *
 * @author BitCtrl Systems GmbH, schumann
 */
public abstract class AbstractDatum implements Datum {

	private final Datensatz datensatz;
	private Aspekt aspekt;

	/**
	 * Initialisiert das Datum.
	 *
	 * @param datensatz
	 *            der Datensatz zu dem das Datum gehört.
	 * @param aspekt
	 *            der Aspekt für das Datum.
	 */
	public AbstractDatum(final Datensatz datensatz, final Aspekt aspekt) {
		this.datensatz = datensatz;
		this.aspekt = aspekt;
	}

	@Override
	public Datensatz dGetDatensatz() {
		return datensatz;
	}

	@Override
	public Aspekt dGetAspekt() {
		return aspekt;
	}

	/**
	 * Setzt den Aspekt des Datums.
	 *
	 * <p>
	 * <em>Hinweis:</em> Diese Methode ist nicht Teil der public-API.
	 *
	 * @param aspekt
	 *            der zu setzende Aspekt.
	 */
	public void dSetAspekt(@SuppressWarnings("hiding") final Aspekt aspekt) {
		this.aspekt = aspekt;
	}

	@Override
	public abstract Datum clone();

}
