package de.bsvrz.sys.funclib.bitctrl.modell.impl;

import de.bsvrz.dav.daf.main.Data;
import de.bsvrz.dav.daf.main.ResultData;
import de.bsvrz.dav.daf.main.config.ConfigurationChangeException;
import de.bsvrz.sys.funclib.bitctrl.modell.Aspekt;
import de.bsvrz.sys.funclib.bitctrl.modell.KonfigurationsDatensatz;
import de.bsvrz.sys.funclib.bitctrl.modell.KonfigurationsDatum;
import de.bsvrz.sys.funclib.bitctrl.modell.ObjektFactory;
import de.bsvrz.sys.funclib.bitctrl.modell.SystemObjekt;

/**
 * Implementiert gemeinsame Methoden der Schnittstelle.
 *
 * @author BitCtrl Systems GmbH, Falko Schumann
 * @param <T>
 *            der Typ des Datensatzes
 */
public abstract class AbstractKonfigurationsDatensatz<T extends KonfigurationsDatum>
		extends AbstractDatensatz<T> implements KonfigurationsDatensatz<T> {

	/**
	 * Initialisiert den Konfigurationsdatensatz.
	 *
	 * @param systemObjekt
	 *            das Systemobjekt zu dem der Datensatz gehört.
	 * @param objektFactory
	 *            die ObjektFabrik, die der Datensatz verwenden soll.
	 */
	public AbstractKonfigurationsDatensatz(final SystemObjekt systemObjekt,
			final ObjektFactory objektFactory) {
		super(systemObjekt, objektFactory);
	}

	@Override
	public T getDatum() {
		final T datum = createDatum();
		final Data data = getSystemObjekt().getSystemObject()
				.getConfigurationData(getSystemObject());
		// TODO Wie wird keine "Keine Rechte" erkannt???
		if (data != null) {
			datum.atl2Bean(data, getObjektFactory());
			return datum;
		}

		return null;
	}

	@Override
	public void setDatum(final T datum) throws ConfigurationChangeException {
		final Data data = konvertiere(datum);
		getSystemObjekt().getSystemObject()
				.setConfigurationData(getSystemObject(), data);
	}

	@Override
	public T getDatum(final Aspekt asp) {
		final T datum = createDatum();
		final Data data = getSystemObjekt().getSystemObject()
				.getConfigurationData(getSystemObject(), getAspect(asp));
		// TODO Wie wird keine "Keine Rechte" erkannt???
		if (data != null) {
			datum.atl2Bean(data, getObjektFactory());
			if (datum instanceof AbstractDatum) {
				((AbstractDatum) datum).dSetAspekt(asp);
			}
			return datum;
		}

		return null;
	}

	@Override
	public void setDatum(final Aspekt asp, final T datum)
			throws ConfigurationChangeException {
		final Data data = konvertiere(datum);
		getSystemObjekt().getSystemObject()
				.setConfigurationData(getSystemObject(), getAspect(asp), data);
	}

	@Override
	public Data konvertiere(final T datum) {
		final Data daten = createSendeCache();
		datum.bean2Atl(daten, getObjektFactory());
		return daten;
	}

	@Override
	public T konvertiere(final ResultData result) {
		check(result);

		final T datum = createDatum();
		if (result.hasData()) {
			final Data daten = result.getData();
			datum.atl2Bean(daten, getObjektFactory());
			return datum;
		}

		return null;
	}

}
