package de.bsvrz.sys.funclib.bitctrl.modell;

import de.bsvrz.dav.daf.main.config.ConfigurationChangeException;

/**
 * Gemeisame Schnittstelle für konfigurierende Datensätze.
 *
 * <p>
 * Konfigurierende Daten besitzen in der Regel den Aspekt
 * <code>asp.eigenschaften</code>. Der Zugriff auf dessen Daten wird durch
 * zusätzliche Methoden vereinfacht. Konfigurierende Daten mit anderen Aspekten
 * können mit den Methoden von {@link Datensatz} verarbeitet werden.
 *
 * @author BitCtrl Systems GmbH, Falko Schumann
 * @param <T>
 *            der Typ des Konfigurationsdatums
 */
public interface KonfigurationsDatensatz<T extends KonfigurationsDatum>
		extends Datensatz<T> {

	/**
	 * Gibt den konfigurierenden Datensatz mit dem Standardaspekt
	 * <code>asp.eigenschaften</code> zurück.
	 *
	 * @return das Datum unter dem Standardaspekt.
	 */
	T getDatum();

	/**
	 * Schreibt das Datum als konfigurierenden Datensatz mit dem Standardaspekt
	 * <code>asp.eigenschaften</code>.
	 *
	 * @param datum
	 *            das zu schreibende Datum.
	 * @throws ConfigurationChangeException
	 *             das Schreiben der Daten in die Konfiguration des
	 *             Datenverteilers ist fehlgeschlagen
	 */
	void setDatum(final T datum) throws ConfigurationChangeException;

	/**
	 * Schreibt das Datum als konfigurierenden Datensatz.
	 *
	 * @param asp
	 *            der Aspekt unter dem das Datum geschrieben weden soll.
	 * @param datum
	 *            das zu schreibende Datum.
	 * @throws ConfigurationChangeException
	 *             das Schreiben der Daten in die Konfiguration des
	 *             Datenverteilers ist fehlgeschlagen
	 */
	void setDatum(final Aspekt asp, final T datum)
			throws ConfigurationChangeException;

}
